//
//  BEAccessibility.h
//  BrowserEngineKit
//
//  Copyright © 2024 Apple Inc. All rights reserved.
//

#import <BrowserEngineKit/BEMacros.h>
#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSInteger, BEAccessibilityPressedState) {
    BEAccessibilityPressedStateUndefined = 0,
    BEAccessibilityPressedStateFalse,
    BEAccessibilityPressedStateTrue,
    BEAccessibilityPressedStateMixed,
} BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

typedef NS_OPTIONS(NSUInteger, BEAccessibilityContainerType) {
    BEAccessibilityContainerTypeNone             = 0,
    BEAccessibilityContainerTypeLandmark         = 1 << 0,
    BEAccessibilityContainerTypeTable            = 1 << 1,
    BEAccessibilityContainerTypeList             = 1 << 2,
    BEAccessibilityContainerTypeFieldset         = 1 << 3,
    BEAccessibilityContainerTypeDialog           = 1 << 4,
    BEAccessibilityContainerTypeTree             = 1 << 5,
    BEAccessibilityContainerTypeFrame            = 1 << 6,
    BEAccessibilityContainerTypeArticle          = 1 << 7,
    BEAccessibilityContainerTypeSemanticGroup    = 1 << 8,
    BEAccessibilityContainerTypeScrollArea       = 1 << 9,
    BEAccessibilityContainerTypeAlert            = 1 << 10,
    BEAccessibilityContainerTypeDescriptionList  = 1 << 11,
} BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

@interface NSObject (BEAccessibility)

/**
 * Represents the value of aria-current.
 * default: nil
 */
@property (nonatomic, strong, nullable) NSString *browserAccessibilityCurrentStatus BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

/**
 * Represents the value of aria-sort.
 * default: nil
 */
@property (nonatomic, strong, nullable) NSString *browserAccessibilitySortDirection BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

/**
 * Represents the value of aria-roledescription.
 * default: nil
 */
@property (nonatomic, strong, nullable) NSString *browserAccessibilityRoleDescription BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

/**
 * Represents the value of aria-required.
 * default: false
 */
@property (nonatomic, assign) BOOL browserAccessibilityIsRequired BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

/**
 * Represents the value of aria-pressed.
 * default: BEAccessibilityPressedStateUndefined
 */
@property (nonatomic, assign) BEAccessibilityPressedState browserAccessibilityPressedState BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

/**
 * Represents whether the current element has native DOM focus.
 * default: false
 */
@property (nonatomic, assign) BOOL browserAccessibilityHasDOMFocus BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

/**
 * An option set of the types that contain this element. For example, an object within a table cell
 * will return the Table container type.
 * default: BEAccessibilityContainerTypeNone
 */
@property (nonatomic, assign) BEAccessibilityContainerType browserAccessibilityContainerType BROWSERENGINE_ACCESSIBILITY_AVAILABILITY;

@end

NS_ASSUME_NONNULL_END
